@@ -16,4 +16,4 @@ class IsOwnerOrReadOnly(permissions.BasePermission):
             return True
 
         # Write permissions are only allowed to the owner of the snippet
-        return obj.author.user == request.user
+        return obj.author == request.user
